@@ -1,30 +1,29 @@
 package Class::Usul;
 
 use 5.010001;
-use feature 'state';
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.57.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.58.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
-use Moo;
 use Class::Usul::Constants  qw( EXCEPTION_CLASS FALSE TRUE );
-use Class::Usul::Functions  qw( data_dumper merge_attributes );
-use Class::Usul::L10N;
-use Class::Usul::Log;
+use Class::Usul::Functions  qw( data_dumper merge_attributes
+                                untaint_identifier );
 use Class::Usul::Types      qw( Bool ConfigType EncodingType HashRef
                                 L10NType LoadableClass LockType LogType );
-use IPC::SRLock;
+use Moo;
 
-# Construction
-my $_build_lock = sub { # Only one lock object. Instantiate on first use
-   my $self = shift; state $cache; $cache and return $cache;
-
-   my $config = $self->config; my $attr = { %{ $config->lock_attributes } };
+# Attribute constructors
+my $_build_lock = sub {
+   my $self   = shift;
+   my $config = $self->config;
+   my $attr   = { %{ $config->lock_attributes } };
 
    merge_attributes $attr, $self,   {}, [ 'debug', 'log' ];
    merge_attributes $attr, $config, { 'exception_class' => EXCEPTION_CLASS },
                                     [ 'exception_class', 'tempdir' ];
 
-   return $cache = IPC::SRLock->new( $attr );
+   $attr->{type} = untaint_identifier $attr->{type};
+
+   return $self->lock_class->new( $attr );
 };
 
 # Public attributes
@@ -44,13 +43,22 @@ has 'encoding'     => is => 'lazy', isa => EncodingType,
    builder         => sub { $_[ 0 ]->config->encoding };
 
 has 'l10n'         => is => 'lazy', isa => L10NType,
-   builder         => sub { Class::Usul::L10N->new( builder => $_[ 0 ] ) },
+   builder         => sub { $_[ 0 ]->l10n_class->new( builder => $_[ 0 ] ) },
    handles         => [ 'localize' ];
 
+has 'l10n_class'   => is => 'lazy', isa => LoadableClass, coerce => TRUE,
+   default         => 'Class::Usul::L10N';
+
 has 'lock'         => is => 'lazy', isa => LockType, builder => $_build_lock;
 
+has 'lock_class'   => is => 'lazy', isa => LoadableClass, coerce => TRUE,
+   default         => 'IPC::SRLock';
+
 has 'log'          => is => 'lazy', isa => LogType,
-   builder         => sub { Class::Usul::Log->new( builder => $_[ 0 ] ) };
+   builder         => sub { $_[ 0 ]->log_class->new( builder => $_[ 0 ] ) };
+
+has 'log_class'    => is => 'lazy', isa => LoadableClass, coerce => TRUE,
+   default         => 'Class::Usul::Log';
 
 # Public methods
 sub dumper { # Damm handy for development
@@ -59,17 +67,26 @@ sub dumper { # Damm handy for development
 
 1;
 
+# <a href="https://travis-ci.org/pjfl/p5-class-usul"><img src="https://travis-ci.org/pjfl/p5-class-usul.svg?branch=master" alt="Travis CI Badge"></a>
+
 __END__
 
 =pod
 
+=begin html
+
+<a href="http://badge.fury.io/pl/Class-Usul"><img src="https://badge.fury.io/pl/Class-Usul.svg" alt="CPAN Badge"></a>
+<a href="http://cpants.cpanauthors.org/dist/Class-Usul"><img src="http://cpants.cpanauthors.org/dist/Class-Usul.png" alt="Kwalitee Badge"></a>
+
+=end html
+
 =head1 Name
 
 Class::Usul - A base class providing config, locking, logging, and l10n
 
 =head1 Version
 
-Describes Class::Usul version v0.57.$Rev: 1 $
+Describes Class::Usul version v0.58.$Rev: 1 $
 
 =head1 Synopsis
 
@@ -107,12 +124,12 @@ Defines the following attributes;
 
 =over 3
 
-=item config
+=item C<config>
 
 The C<config> attribute should be a hash reference that may define key / value
 pairs that provide filesystem paths for the temporary directory etc.
 
-=item config_class
+=item C<config_class>
 
 Defaults to L<Class::Usul::Config> and is of type C<LoadableClass>. An
 instance of this class is loaded and instantiated using the hash reference
@@ -120,32 +137,47 @@ in the C<config> attribute. It provides accessor methods with symbol
 inflation and smart defaults. Add configuration attributes by
 subclassing this class
 
-=item debug
+=item C<debug>
 
-Defaults to false
+A boolean which defaults to false. Usually an instance of this class is passed
+into the constructors of other classes which set their own debug state to this
+value
 
-=item encoding
+=item C<encoding>
 
-Decode input and encode output. Defaults to C<< $self->config->encoding >>
-which defaults to to C<UTF-8>
+Defaults to C<< $self->config->encoding >> which defaults to to C<UTF-8>.
+Used to decode input and encode output
 
-=item l10n
+=item C<l10n>
 
-An instance of L<Class::Usul::L10N>
+A lazily evaluated instance of the C<l10n_class>. This object reference handles
+the C<localize> method
 
-=item lock
+=item C<l10n_class>
 
-An instance of L<IPC::SRLock>
+A lazy loadable class which defaults to L<Class::Usul::L10N>
 
-=item log
+=item C<lock>
 
-An instance of L<Class::Usul::Log>
+A lazily evaluated instance of the C<lock_class>
+
+=item C<lock_class>
+
+A lazy loadable class which defaults to L<IPC::SRLock>
+
+=item C<log>
+
+A lazily evaluated instance of the C<log_class>
+
+=item C<log_class>
+
+A lazy loadable class which defaults to L<Class::Usul::Log>
 
 =back
 
 =head1 Subroutines/Methods
 
-=head2 dumper
+=head2 C<dumper>
 
    $self->dumper( $some_var );
 
@@ -160,6 +192,8 @@ debug level
 
 =over 3
 
+=item L<Class::Usul::Config>
+
 =item L<Class::Usul::Constants>
 
 =item L<Class::Usul::Functions>
@@ -168,6 +202,8 @@ debug level
 
 =item L<Class::Usul::Log>
 
+=item L<Class::Usul::Types>
+
 =item L<IPC::SRLock>
 
 =item L<Moo>
