@@ -2,14 +2,14 @@ package Class::Usul::Config;
 
 use namespace::autoclean;
 
-use Moo;
 use Class::Usul::Constants   qw( CONFIG_EXTN DEFAULT_CONFHOME
                                  DEFAULT_ENCODING DEFAULT_L10N_DOMAIN
                                  FALSE LANG NUL PERL_EXTNS PHASE TRUE );
 use Class::Usul::File;
 use Class::Usul::Functions   qw( app_prefix canonicalise class2appdir
                                  home2appldir is_arrayref split_on__
-                                 split_on_dash untaint_path );
+                                 split_on_dash untaint_cmdline
+                                 untaint_identifier untaint_path );
 use Class::Usul::Types       qw( ArrayRef EncodingType HashRef NonEmptySimpleStr
                                  NonZeroPositiveInt PositiveInt Str );
 use Config;
@@ -20,6 +20,7 @@ use File::Gettext::Constants qw( LOCALE_DIRS );
 use File::Spec::Functions    qw( canonpath catdir catfile
                                  rel2abs rootdir tmpdir );
 use Scalar::Util             qw( blessed );
+use Moo;
 
 # Public attributes
 has 'appclass'  => is => 'ro',   isa => NonEmptySimpleStr, required => TRUE;
@@ -35,6 +36,8 @@ has 'ctlfile'   => is => 'lazy', isa => Path, coerce => TRUE;
 
 has 'ctrldir'   => is => 'lazy', isa => Path, coerce => TRUE;
 
+has 'datadir'   => is => 'lazy', isa => Path, coerce => TRUE;
+
 has 'encoding'  => is => 'ro',   isa => EncodingType, coerce => TRUE,
    default      => DEFAULT_ENCODING;
 
@@ -61,7 +64,8 @@ has 'no_thrash' => is => 'ro',   isa => NonZeroPositiveInt, default => 3;
 
 has 'phase'     => is => 'lazy', isa => PositiveInt;
 
-has 'prefix'    => is => 'lazy', isa => NonEmptySimpleStr;
+has 'prefix'    => is => 'lazy', isa => NonEmptySimpleStr,
+   coerce       => sub { untaint_cmdline $_[ 0 ] };
 
 has 'pathname'  => is => 'lazy', isa => File, coerce => TRUE;
 
@@ -167,6 +171,12 @@ sub _build_ctrldir {
    return [ NUL, qw( usr local etc ) ];
 }
 
+sub _build_datadir {
+   my $dir = $_[ 0 ]->inflate_path( $_[ 1 ], 'vardir', 'data' );
+
+   return -d $dir ? $dir : $_[ 0 ]->inflate_path( $_[ 1 ], 'tempdir' );
+}
+
 sub _build_localedir {
    my $dir = $_[ 0 ]->inflate_path( $_[ 1 ], 'vardir', 'locale' );
 
@@ -248,7 +258,7 @@ sub _build_shell {
 }
 
 sub _build_salt {
-   return $_[ 0 ]->inflate_symbol( $_[ 1 ], 'prefix' );
+   return untaint_cmdline $_[ 0 ]->inflate_symbol( $_[ 1 ], 'prefix' );
 }
 
 sub _build_suid {
@@ -304,15 +314,36 @@ __END__
 
 =head1 Name
 
-Class::Usul::Config - Inflate config values
+Class::Usul::Config - Configuration class with sensible attribute defaults
 
 =head1 Synopsis
 
-   use Class::Usul::Config;
+   use Class::Usul::Constants qw( TRUE );
+   use Class::Usul::Types     qw( ConfigType HashRef LoadableClass );
+   use Moo;
+
+   has 'config'       => is => 'lazy', isa => ConfigType, builder => sub {
+      $_[ 0 ]->config_class->new( $_[ 0 ]->_config_attr ) },
+      init_arg        => undef;
+
+   has '_config_attr' => is => 'ro',   isa => HashRef, builder => sub { {} },
+      init_arg        => 'config';
+
+   has 'config_class' => is => 'ro',   isa => LoadableClass, coerce => TRUE,
+      default         => 'Class::Usul::Config';
 
 =head1 Description
 
-Defines the following list of attributes
+Defines the configuration object. Attributes have sensible defaults that
+can be overridden by values in configuration files which are loaded on
+request
+
+Pathnames passed in the C<cfgfiles> attribute are loaded and their contents
+merged with the values passed to the configuration class constructor
+
+=head1 Configuration and Environment
+
+Defines the following list of attributes;
 
 =over 3
 
@@ -327,7 +358,7 @@ Directory. Defaults to the application's install directory
 
 =item C<binsdir>
 
-Directory. Defaults to the application's I<bin> directory
+Directory. Defaults to the application's F<bin> directory
 
 =item C<cfgfiles>
 
@@ -336,19 +367,23 @@ files to load when instantiating an instance of the configuration class
 
 =item C<ctlfile>
 
-File in the C<ctrldir> directory that contains this programs control data
+File in the F<ctrldir> directory that contains this programs control data
 
 =item C<ctrldir>
 
 Directory containing the per program configuration files
 
+=item C<datadir>
+
+Directory containing data files used by the application
+
 =item C<encoding>
 
-String default to the constant I<DEFAULT_ENCODING>
+String default to the constant C<DEFAULT_ENCODING>
 
 =item C<extension>
 
-String defaults to the constant I<CONFIG_EXTN>
+String defaults to the constant C<CONFIG_EXTN>
 
 =item C<home>
 
@@ -356,7 +391,7 @@ Directory containing the config file. Required
 
 =item C<l10n_attributes>
 
-Hash ref of attributes used to construct a L<Class::Usul::L10N>
+Hash reference of attributes used to construct a L<Class::Usul::L10N>
 object. By default contains one key, C<domains>, an array reference
 which defaults to the constant C<DEFAULT_L10N_DOMAIN> and the
 applications configuration name. The filename(s) used to translate
@@ -379,11 +414,11 @@ contains only the constant C<LANG>
 
 =item C<lock_attributes>
 
-Hash ref of attributes used to construct an L<IPC::SRLock> object
+Hash reference of attributes used to construct an L<IPC::SRLock> object
 
 =item C<log_attributes>
 
-Hash ref of attributes used to construct a L<Class::Usul::Log> object
+Hash reference of attributes used to construct a L<Class::Usul::Log> object
 
 =item C<logfile>
 
@@ -404,7 +439,7 @@ avoid processor thrash
 
 =item C<pathname>
 
-File defaults to the absolute path to the I<PROGRAM_NAME> system constant
+File defaults to the absolute path to the C<PROGRAM_NAME> system constant
 
 =item C<phase>
 
@@ -426,7 +461,7 @@ Directory. Contains a running programs PID file
 =item C<salt>
 
 String. This applications salt for passwords as set by the administrators . It
-is used to perturb the encryption methods. Defaults to the I<prefix>
+is used to perturb the encryption methods. Defaults to the C<prefix>
 attribute value
 
 =item C<sessdir>
@@ -443,8 +478,8 @@ File. The default shell used to create new OS users
 
 =item C<suid>
 
-File. Name of the setuid root program in the I<bin> directory. Defaults to
-the I<prefix>_admin
+File. Name of the setuid root program in the F<bin> directory. Defaults to
+the C<prefix>_admin
 
 =item C<tempdir>
 
@@ -461,12 +496,12 @@ Directory. Contains all of the non program code directories
 
 =head2 BUILDARGS
 
-Loads the configuration files if specified. Calls L</inflate_symbol>
-and L</inflate_path>
+Loads the configuration files if specified in the C<cfgfiles> attribute. Calls
+L</inflate_symbol> and L</inflate_path> as required
 
 =head2 inflate_path
 
-Inflates the I<__symbol( relative_path )__> values to their actual runtime
+Inflates the C<__symbol( relative_path )__> values to their actual runtime
 values
 
 =head2 inflate_paths
@@ -476,11 +511,7 @@ was passed as argument
 
 =head2 inflate_symbol
 
-Inflates the I<__SYMBOL__> values to their actual runtime values
-
-=head1 Configuration and Environment
-
-None
+Inflates the C<__SYMBOL__> values to their actual runtime values
 
 =head1 Diagnostics
 
