@@ -3,7 +3,6 @@ package Class::Usul::L10N;
 use 5.010001;
 use namespace::autoclean;
 
-use Moo;
 use Class::Null;
 use Class::Usul::Constants   qw( FALSE LBRACE LOCALIZE NUL SEP TRUE );
 use Class::Usul::Functions   qw( assert is_arrayref
@@ -15,6 +14,8 @@ use File::Gettext::Constants qw( CONTEXT_SEP );
 use File::Gettext;
 use File::Spec;
 use Try::Tiny;
+use Unexpected::Functions    qw( inflate_placeholders );
+use Moo;
 
 my $Domain_Cache = {}; my $Locale_Cache = {};
 
@@ -152,12 +153,8 @@ sub localize {
       0 > index $text, LOCALIZE and return $text;
 
       # Expand positional parameters of the form [_<n>]
-      my @args = map { $args->{quote_bind_values} ? "'${_}'" : $_ }
-                 map { (length) ? $_  : '[]'  }
-                 map {            $_ // '[?]' } @{ $args->{params} },
-                 map {                  '[?]' } 0 .. 9;
-
-      $text =~ s{ \[ _ (\d+) \] }{$args[ $1 - 1 ]}gmx; return $text;
+      return inflate_placeholders [ '[?]', '[]', !$args->{quote_bind_values} ],
+                                  $text, @{ $args->{params} };
    }
 
    0 > index $text, LBRACE and return $text;
