@@ -4,7 +4,6 @@ use attributes ();
 use feature 'state';
 use namespace::autoclean;
 
-use Moo;
 use Class::Inspector;
 use Class::Usul::Constants qw( BRK FAILED FALSE NUL OK
                                SPC TRUE UNDEFINED_RV WIDTH );
@@ -12,10 +11,9 @@ use Class::Usul::File;
 use Class::Usul::Functions qw( abs_path elapsed emit emit_err emit_to
                                ensure_class_loaded env_prefix exception
                                find_apphome find_source get_cfgfiles
-                               is_arrayref is_hashref is_member logname pad
-                               throw untaint_cmdline );
+                               is_arrayref is_hashref is_member list_attr_of
+                               logname pad throw untaint_cmdline );
 use Class::Usul::IPC;
-use Class::Usul::Options;
 use Class::Usul::Types     qw( ArrayRef Bool EncodingType FileType HashRef
                                Int IPCType LoadableClass PositiveInt
                                PromptType SimpleStr );
@@ -27,6 +25,8 @@ use List::Util             qw( first );
 use Scalar::Util           qw( blessed );
 use Text::Autoformat;
 use Try::Tiny;
+use Moo;
+use Class::Usul::Options;
 
 extends q(Class::Usul);
 with    q(Class::Usul::TraitFor::Prompting);
@@ -36,51 +36,17 @@ my $_dash2underscore = sub {
    (my $x = $_[ 0 ] || NUL) =~ s{ [\-] }{_}gmx; return $x;
 };
 
-my $_get_pod_content_for_attr = sub {
-   my ($class, $attr) = @_; my $pod;
-
-   my $src    = find_source $class
-      or throw 'Class [_1] cannot find source', [ $class ];
-   my $events = Pod::Eventual::Simple->read_file( $src );
-
-   for (my $ev_no = 0, my $max = @{ $events }; $ev_no < $max; $ev_no++) {
-      my $ev = $events->[ $ev_no ]; $ev->{type} eq 'command' or next;
-
-      $ev->{content} =~ m{ (?: ^|[< ]) $attr (?: [ >]|$ ) }msx or next;
-
-      $ev_no++ while ($ev = $events->[ $ev_no + 1 ] and $ev->{type} eq 'blank');
-
-      $ev and $ev->{type} eq 'text' and $pod = $ev->{content} and last;
-   }
-
-   $pod //= 'Undocumented'; $pod and chomp $pod; $pod =~ s{ [\n] }{ }gmx;
-
-   return $pod;
-};
-
 my $_get_pod_header_for_method = sub {
    my ($class, $method) = @_;
 
    my $src = find_source $class
       or throw 'Class [_1] cannot find source', [ $class ];
-   my $pod = Pod::Eventual::Simple->read_file( $src );
-   my $out = [ grep { $_->{content} =~ m{ (?: ^|[< ]) $method (?: [ >]|$ ) }msx}
-               grep { $_->{type} eq 'command' } @{ $pod } ]->[ 0 ]->{content};
+   my $ev  = [ grep { $_->{content} =~ m{ (?: ^|[< ]) $method (?: [ >]|$ ) }msx}
+               grep { $_->{type} eq 'command' }
+                   @{ Pod::Eventual::Simple->read_file( $src ) } ]->[ 0 ];
+   my $pod = $ev ? $ev->{content} : undef; $pod and chomp $pod;
 
-   $out and chomp $out;
-   return $out;
-};
-
-my $_list_attr_of = sub {
-   my ($obj, @except) = @_; my $class = blessed $obj;
-
-   ensure_class_loaded 'Pod::Eventual::Simple';
-
-   return map  { my $attr = $_->[0]; [ @{ $_ }, $obj->$attr ] }
-          map  { [ $_->[1], $_->[0], $_get_pod_content_for_attr->( @{ $_ } ) ] }
-          grep { $_->[0] ne 'Moo::Object' and not is_member $_->[1], @except }
-          map  { m{ \A (.+) \:\: ([^:]+) \z }mx; [ $1, $2 ] }
-              @{ Class::Inspector->methods( $class, 'full', 'public' ) };
+   return $pod;
 };
 
 my $_list_methods_of = sub {
@@ -102,7 +68,7 @@ my $_output_stacktrace = sub {
    return;
 };
 
-# Construction methods
+# Attribute constructors
 my $_build_debug = sub {
    my $self = shift; my $k = (env_prefix $self->config->appclass).'_DEBUG';
 
@@ -136,7 +102,7 @@ my $_build_run_method = sub {
    return $self->_set_method( $method );
 };
 
-# Override attributes in base class
+# Override attribute default in base class
 has '+config_class'   => default => 'Class::Usul::Config::Programs';
 
 # Public attributes
@@ -160,17 +126,17 @@ option 'help_usage'   => is => 'ro',   isa => Bool, default => FALSE,
    documentation      => 'Displays this command line usage',
    short              => '?';
 
-option 'home'         => is => 'lazy', isa => Directory, format => 's',
+option 'home'         => is => 'lazy', isa => Directory, coerce => TRUE,
    documentation      => 'Directory containing the configuration file',
-   default            => sub { $_[ 0 ]->config->home }, coerce  => TRUE;
+   default            => sub { $_[ 0 ]->config->home },  format => 's';
 
 option 'locale'       => is => 'ro',   isa => SimpleStr, format => 's',
    documentation      => 'Loads the specified language message catalogue',
    default            => sub { $_[ 0 ]->config->locale }, short => 'L';
 
-option 'method'       => is => 'rwp',  isa => SimpleStr, format => 's',
+option 'method'       => is => 'rwp',  isa => SimpleStr, default => NUL,
    documentation      => 'Name of the method to call',
-   default            => NUL, order => 1, short => 'c';
+   format             => 's', order => 1, short => 'c';
 
 option 'noask'        => is => 'ro',   isa => Bool, default => FALSE,
    documentation      => 'Do not prompt for debugging',
@@ -193,9 +159,6 @@ option 'verbose'      => is => 'ro',   isa => Int,  default => 0,
    documentation      => 'Increase the verbosity of the output',
    repeatable         => TRUE, short => 'v';
 
-has 'meta_class'  => is => 'lazy', isa => LoadableClass, coerce => TRUE,
-   default        => 'Class::Usul::Response::Meta';
-
 has 'mode'        => is => 'rw',   isa => OctalNum, coerce => TRUE,
    default        => sub { $_[ 0 ]->config->mode }, lazy => TRUE;
 
@@ -223,7 +186,7 @@ has '_run_method' => is => 'lazy', isa => SimpleStr,
 
 # Private methods
 my $_apply_stdio_encoding = sub {
-   my $self = shift; my $enc = $self->encoding;
+   my $self = shift; my $enc = untaint_cmdline $self->encoding;
 
    for (*STDIN, *STDOUT, *STDERR) {
       $_->opened or next; binmode $_, ":encoding(${enc})";
@@ -244,6 +207,7 @@ my $_catch_run_exception = sub {
 
    $e->out and $self->output( $e->out );
    $self->error( $e->error, { args => $e->args } );
+   $self->debug and $_output_stacktrace->( $error, $self->verbose );
 
    return $e->rv || (defined $e->rv ? FAILED : UNDEFINED_RV);
 };
@@ -279,9 +243,11 @@ my $_get_debug_option = sub {
 };
 
 my $_version = sub {
-   my $self = shift; no strict 'refs';
+   my $self = shift; my $conf = $self->config;
 
-   return ${ $self->config->appclass.'::VERSION' } // '?';
+   try { ensure_class_loaded $conf->appclass } catch {}; no strict 'refs';
+
+   return ${ $conf->appclass.'::VERSION' } // '?';
 };
 
 my $_exit_version = sub {
@@ -289,16 +255,15 @@ my $_exit_version = sub {
 };
 
 my $_man_page_from = sub {
-   my ($self, $src) = @_; my $cfg = $self->config;
+   my ($self, $src) = @_; ensure_class_loaded 'Pod::Man';
 
-   ensure_class_loaded 'Pod::Man';
-
-   my $parser   = Pod::Man->new( center  => $cfg->doc_title || NUL,
-                                 name    => $cfg->script,
+   my $conf     = $self->config;
+   my $parser   = Pod::Man->new( center  => $conf->doc_title || NUL,
+                                 name    => $conf->script,
                                  release => 'Version '.$self->$_version,
                                  section => '3m' );
+   my $cmd      = $conf->man_page_cmd || [];
    my $tempfile = $self->file->tempfile;
-   my $cmd      = $cfg->man_page_cmd || [];
 
    $parser->parse_from_file( NUL.$src->pathname, $tempfile->pathname );
    emit $self->run_cmd( [ @{ $cmd }, $tempfile->pathname ] )->out;
@@ -319,6 +284,7 @@ my $_usage_for = sub {
       $tfile->stat->{size} > 0 and return $self->$_man_page_from( $tfile );
    }
 
+   emit_to \*STDERR, "Method ${method} no documentation found\n";
    return FAILED;
 };
 
@@ -341,10 +307,6 @@ my $_output_usage = sub {
    return FAILED;
 };
 
-my $_exit_usage = sub {
-   $_[ 0 ]->quiet( TRUE ); exit $_[ 0 ]->$_output_usage( $_[ 1 ] );
-};
-
 # Construction
 around 'BUILDARGS' => sub {
    my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
@@ -361,9 +323,9 @@ around 'BUILDARGS' => sub {
 sub BUILD {
    my $self = shift; $self->$_apply_stdio_encoding;
 
-   $self->help_usage   and $self->$_exit_usage( 0 );
-   $self->help_options and $self->$_exit_usage( 1 );
-   $self->help_manual  and $self->$_exit_usage( 2 );
+   $self->help_usage   and $self->exit_usage( 0 );
+   $self->help_options and $self->exit_usage( 1 );
+   $self->help_manual  and $self->exit_usage( 2 );
    $self->show_version and $self->$_exit_version;
 
    $self->_set_debug( $self->$_get_debug_option );
@@ -377,7 +339,7 @@ sub add_leader {
    my $leader = $args->{no_lead} ? NUL : (ucfirst $self->config->name).BRK;
 
    if ($args->{fill}) {
-      my $width = $args->{width} || WIDTH;
+      my $width = $args->{width} // WIDTH;
 
       $text = autoformat $text, { right => $width - 1 - length $leader };
    }
@@ -403,7 +365,7 @@ sub dump_config_attr : method {
    my $self = shift; my @except =
       qw( BUILDARGS BUILD inflate_path inflate_paths inflate_symbol new secret);
 
-   $self->dumper( [ $_list_attr_of->( $self->config, @except ) ] );
+   $self->dumper( [ list_attr_of $self->config, @except ] );
 
    return OK;
 }
@@ -416,28 +378,30 @@ sub dump_self : method {
 }
 
 sub error {
-   my ($self, $err, $args) = @_;
+   my ($self, $text, $args) = @_;
 
-   my $text = $self->loc( $err || '[no message]', $args->{args} || [] );
+   $text = $self->loc( $text || '[no message]', $args->{args} // [] );
 
    $self->log->error( $_ ) for (split m{ \n }mx, "${text}");
 
    emit_to *STDERR, $self->add_leader( $text, $args )."\n";
-   $self->debug and $_output_stacktrace->( $err, $self->verbose );
    return TRUE;
 }
 
+sub exit_usage {
+   $_[ 0 ]->quiet( TRUE ); exit $_[ 0 ]->$_output_usage( $_[ 1 ] );
+}
+
 sub fatal {
-   my ($self, $err, $args) = @_; my (undef, $file, $line) = caller 0;
+   my ($self, $text, $args) = @_; my (undef, $file, $line) = caller 0;
 
    my $posn = ' at '.abs_path( $file )." line ${line}";
 
-   my $text = $self->loc( $err || '[no message]', $args->{args} || [] );
+   $text = $self->loc( $text || '[no message]', $args->{args} // [] );
 
    $self->log->alert( $_ ) for (split m{ \n }mx, $text.$posn);
 
-   emit_to *STDERR, $self->add_leader( $text, $args ).$posn."\n";
-   $_output_stacktrace->( $err, $self->verbose );
+   emit_to *STDERR, $self->add_leader( $text, $args )."${posn}\n";
    exit FAILED;
 }
 
@@ -448,7 +412,7 @@ sub help : method {
 sub info {
    my ($self, $text, $args) = @_;
 
-   my $opts = { params => $args->{args} || [], quote_bind_values => FALSE, };
+   my $opts = { params => $args->{args} // [], quote_bind_values => FALSE, };
 
    $text = $self->loc( $text || '[no message]', $opts );
 
@@ -458,14 +422,6 @@ sub info {
    return TRUE;
 }
 
-sub interpolate_cmd {
-   my ($self, $cmd, @args) = @_;
-
-   my $ref = $self->can( "_interpolate_${cmd}_cmd" ) or return [ $cmd, @args ];
-
-   return $self->$ref( $cmd, @args );
-}
-
 sub list_methods : method {
    my $self = shift; ensure_class_loaded 'Pod::Eventual::Simple';
 
@@ -510,7 +466,7 @@ sub loc {
 sub output {
    my ($self, $text, $args) = @_; $args ||= {};
 
-   $text = $self->loc( $text || '[no message]', $args->{args} || [] );
+   $text = $self->loc( $text || '[no message]', $args->{args} // [] );
 
    my $code = sub {
       $args->{to} && $args->{to} eq 'err' ? emit_err( @_ ) : emit( @_ );
@@ -572,7 +528,7 @@ sub run {
 sub run_chain {
    my $self = shift;
 
-   $self->error( 'Method unknown' ); $self->$_exit_usage( 0 );
+   $self->error( 'Method unknown' ); $self->exit_usage( 0 );
 
    return; # Not reached
 }
@@ -580,7 +536,7 @@ sub run_chain {
 sub warning {
    my ($self, $text, $args) = @_;
 
-   $text = $self->loc( $text || '[no message]', $args->{args} || [] );
+   $text = $self->loc( $text || '[no message]', $args->{args} // [] );
 
    $self->log->warn( $_ ) for (split m{ \n }mx, $text);
 
@@ -658,10 +614,14 @@ from the C<< $self->options >> hash ref
 
 Quietens the usual started/finished information messages
 
-=item C<show_version>
+=item C<V show_version>
 
 Prints the programs version number and exits
 
+=item C<v verbose>
+
+Repeatable boolean that increases the verbosity of the output
+
 =back
 
 Defines these attributes;
@@ -677,14 +637,29 @@ C<Class::Usul::Config::Programs>
 
 List of value that are passed to the method called by L</run>
 
-=item C<v verbose>
-
-Repeatable boolean that increases the verbosity of the output
-
 =back
 
 =head1 Subroutines/Methods
 
+=head2 dump_config_attr - Dumps the configuration attributes and values
+
+Visits the configuration object, forcing evaluation of the lazy, and printing
+out the attributes and values
+
+=head2 dump_self - Dumps the program object
+
+Dumps out the self referential object using L<Data::Printer>
+
+=head2 help - Display help text about a method
+
+Searches the programs classes and roles to find the method implementation.
+Displays help text from the POD that describes the method
+
+=head2 list_methods - Lists available command line methods
+
+Lists the methods (marked by the I<method> subroutine attribute) that can
+be called via the L<run method|/run>
+
 =head2 BUILDARGS
 
 Called just before the object is constructed this method modifier determines
@@ -716,19 +691,6 @@ the I<method> method attribute
 
 Returns the command line debug flag to match the current debug state
 
-=head2 dump_config_attr - Dumps the configuration attributes and values
-
-   $self->dump_config_attr;
-
-Visits the configuration object, forcing evaluation of the lazy, and printing
-out the attributes and values
-
-=head2 dump_self - Dumps the program object
-
-   $self->dump_self;
-
-Dumps out the self referential object using L<Data::Printer>
-
 =head2 error
 
    $self->error( $text, $args );
@@ -737,9 +699,9 @@ Calls L<Class::Usul::localize|Class::Usul/localize> with
 the passed args. Logs the result at the error level, then adds the
 program leader and prints the result to I<STDERR>
 
-=head2 _exit_usage
+=head2 exit_usage
 
-   $self->_exit_usage( $verbosity );
+   $self->exit_usage( $verbosity );
 
 Print out usage information from POD. The C<$verbosity> is; 0, 1 or 2
 
@@ -765,13 +727,6 @@ code of one
 If it is an interactive session prompts the user to turn debugging
 on. Returns true if debug is on. Also offers the option to quit
 
-=head2 help - Display help text about a method
-
-   $exit_code = $self->help;
-
-Searches the programs classes and roles to find the method implementation.
-Displays help text from the POD that describes the method
-
 =head2 info
 
    $self->info( $text, $args );
@@ -780,20 +735,6 @@ Calls L<Class::Usul::localize|Class::Usul/localize> with
 the passed args. Logs the result at the info level, then adds the
 program leader and prints the result to I<STDOUT>
 
-=head2 interpolate_cmd
-
-   $cmd = $self->interpolate_cmd( $cmd, @args );
-
-Calls C<_interpolate_${cmd}_cmd> to apply the arguments to the command in a
-command specific way
-
-=head2 list_methods - Lists available command line methods
-
-   $self->list_methods;
-
-Lists the methods (marked by the I<method> subroutine attribute) that can
-be called via the L<run method|/run>
-
 =head2 loc
 
    $localized_text = $self->loc( $message, @options );
