@@ -75,12 +75,12 @@ my $_extract_creds_from = sub {
 my $_get_connect_options = sub {
    my $creds = shift;
    my $uopt  = $creds->{unicode_option}
-            || $_unicode_options->()->{ lc $creds->{driver} } || {};
+            // $_unicode_options->()->{ lc $creds->{driver} } // {};
 
    return { AutoCommit =>  $creds->{auto_commit  } // TRUE,
             PrintError =>  $creds->{print_error  } // FALSE,
             RaiseError =>  $creds->{raise_error  } // TRUE,
-            %{ $uopt }, %{ $creds->{database_attr} || {} }, };
+            %{ $uopt }, %{ $creds->{database_attr} // {} }, };
 };
 
 my $_load_config_data = sub {
@@ -124,11 +124,13 @@ sub get_connect_info {
 
    my $cfg_data = $_load_config_data->( $param );
    my $creds    = $_extract_creds_from->( $param, $cfg_data );
-   my $dsn      = 'dbi:'.$creds->{driver}.':database='.$param->{database}
-                  .';host='.$creds->{host}.';port='.$creds->{port};
+   my $dsn      = 'dbi:'.$creds->{driver}.':database='.$param->{database};
    my $password = decrypt_from_config $param, $creds->{password};
    my $opts     = $_get_connect_options->( $creds );
 
+   $creds->{host} and $dsn .= ';host='.$creds->{host};
+   $creds->{port} and $dsn .= ';port='.$creds->{port};
+
    return $cache->{ $key } = [ $dsn, $creds->{user}, $password, $opts ];
 }
 
